List of highest mountains on Earth - Wikipedia

# List of highest mountains on Earth

From Wikipedia, the free encyclopedia
Jump to navigation Jump to search
Wikimedia list article

| This article possibly contains original research. Please improve it by verifying the claims made and adding inline citations. Statements consisting only of original research should be removed. (September 2021) (Learn how and when to remove this template message)

Aerial view of Mount Everest from the south. The peak rises over Lhotse, while Nuptse is the ridge on the left.

There are at least 108 mountains on Earth with elevations of 7,200 metres (23,622 ft) or greater above sea level. The vast majority of these mountains are located on the edge of the Indian and Eurasian plates in China, India, Nepal and Pakistan.

Figure demonstrating the concept of topographic prominence: The prominence of a peak is the height of the peak's summit above the lowest contour line encircling it and no higher summit. For example, vertical arrows show the topographic prominence of three peaks on an island. A dotted horizontal line links each peak (except the highest) to its key col.

The dividing line between a mountain with multiple peaks and separate mountains is not always clear (see also Highest unclimbed mountain). A popular and intuitive way to distinguish mountains from subsidiary peaks is by their height above the highest saddle connecting it to a higher summit, a measure called topographic prominence or re-ascent (the higher summit is called the "parent peak"). A common definition of a mountain is a summit with 300 m (980 ft) prominence. Alternatively, a relative prominence (prominence/height) is used (usually 7–8%) to reflect that in higher mountain ranges everything is on a larger scale. The table below lists the highest 100 summits with at least 500 m (1,640 ft) prominence, approximating a 7% relative prominence. A drawback of a prominence-based list is that it may exclude well-known or spectacular mountains that are connected via a high ridge to a taller summit, such as Eiger, Nuptse or Annapurna IV. A few such peaks and mountains with nearly sufficient prominence are included in this list, and given a rank of "S".

It is very unlikely that all given heights are correct to the nearest metre; indeed, the sea level is often problematic to define when a mountain is remote from the sea. Different sources often differ by many metres, and the heights given below may well differ from those elsewhere in this encyclopedia. As an extreme example, Ulugh Muztagh on the north Tibetan Plateau is often listed as 7,723 m (25,338 ft) to 7,754 m (25,440 ft), but appears to be only 6,973 m (22,877 ft) to 6,987 m (22,923 ft). Some mountains differ by > 100 m (330 ft) on different maps, while even very thorough current measurements of Mount Everest range from 8,840 m (29,003 ft) to 8,850 m (29,035 ft). These discrepancies serve to emphasize the uncertainties in the listed heights.

Though some parts of the world, especially the most mountainous parts, have never been thoroughly mapped, it is unlikely that any mountains this high have been overlooked, because synthetic aperture radar can and has been used to measure elevations of most otherwise inaccessible places. Still, heights or prominences may be revised, so that the order of the list may change and even "new" mountains could enter the list over time. To be safe, the list has been extended to include all 7,200 m (23,622 ft) peaks.

The highest mountains above sea level are generally not the highest above the surrounding terrain. There is no precise definition of surrounding base, but Denali, Mount Kilimanjaro and Nanga Parbat are possible candidates for the tallest mountain on land by this measure.[citation needed] The bases of mountain islands are below sea level, and given this consideration Mauna Kea (4,207 m (13,802 ft) above sea level) is the world's tallest mountain and volcano, rising about 10,203 m (33,474 ft) from the Pacific Ocean floor. Mount Lamlam on Guam is periodically claimed to be among the world's highest mountains because it is adjacent to the Mariana Trench; the most extreme claim is that, measured from Challenger Deep 313 kilometres (194 mi) away, Mount Lamlam is 37,820 feet (11,530 m) tall.[1][2] Ojos del Salado has the greatest rise on Earth: 13,420 m (44,029 ft) vertically to the summit[citation needed] from the bottom of the Atacama Trench, which is about 560 km (350 mi) away, although most of this rise is not part of the mountain.

The highest mountains are also not generally the most voluminous. Mauna Loa (4,169 m or 13,678 ft) is the largest mountain on Earth in terms of base area (about 2,000 sq mi or 5,200 km2) and volume (about 10,000 cu mi or 42,000 km3), although, due to the intergrade of lava from Kilauea, Hualalai and Mauna Kea, the volume can only be estimated based on surface area and height of the edifice. Mount Kilimanjaro is the largest non-shield volcano in terms of both base area (245 sq mi or 635 km2) and volume (1,150 cu mi or 4,793 km3). Mount Logan is the largest non-volcanic mountain in base area (120 sq mi or 311 km2).

The highest mountains above sea level are also not those with peaks farthest from the centre of the Earth, because the figure of the Earth is not spherical. Sea level closer to the equator is several kilometres farther from the centre of the Earth. The summit of Chimborazo, Ecuador's tallest mountain, is usually considered to be the farthest point from the Earth's centre, although the southern summit of Peru's tallest mountain, Huascarán, is another contender.[3] Both have elevations above sea level more than 2 km less than that of Everest.

## Geographical distribution[edit]

Map all coordinates using: OpenStreetMap
Download coordinates as: KML

Almost all mountains in the list are located in the Himalaya and Karakoram ranges to the south and west of the Tibetan plateau. All peaks 7,000 m (23,000 ft) or higher are located in East, Central or South Asia in a rectangle edged by Noshaq (7,492 m or 24,580 ft) on the Afghanistan–Pakistan border in the west, Jengish Chokusu (Tuōmù'ěr Fēng, 7,439 m or 24,406 ft) on the Kyrgyzstan–Xinjiang border to the north, Gongga Shan (Minya Konka, 7,556 m or 24,790 ft) in Sichuan to the east, and Kabru (7,412 m or 24,318 ft) on the Sikkim–Nepal border to the south.

As of December 2018[update], the highest peaks on four of the mountains — Gangkhar Puensum, Labuche Kang III, Karjiang, and Tongshanjiabu, all located in Bhutan or China — have not been ascended. The most recent peak to have its first ever ascent is Saser Kangri II East, in India, on 24 August 2011.

The highest mountain outside of Asia is Aconcagua (6,961 m or 22,838 ft), the 189th highest in the world.[4]

## List of world's highest peaks[edit]

Rank [dp 1] | Mountain name(s) | Height (rounded) [dp 2] | Prominence (rounded) [dp 3] | Range | Coordinates [dp 4] | Parent mountain [dp 5] | Ascents before 2004[dp 6] | Country
--- | --- | --- | --- | --- | --- | --- | --- | ---
1st | successful
m | ft | m | ft | y | n
1 | Mount Everest Sagarmatha Chomolungma | 8,848 | 29,029 [dp 7] | 8,848 | 29,029 | Mahalangur Himalaya | 27°59′17″N 86°55′31″E﻿ / ﻿27.9881°N 86.9253°E﻿ / 27.9881; 86.9253﻿ (1. Mount Everest / Sagarmatha / Chomolungma / Zhumulangma (8848 m)) | — | 1953 | 145 | 121 | Nepal China
2 | K2 | 8,611 | 28,251 | 4,020 | 13,190 | Baltoro Karakoram | 35°52′53″N 76°30′48″E﻿ / ﻿35.88139°N 76.51333°E﻿ / 35.88139; 76.51333﻿ (2. K2 / Qogir / Godwin Austen (8611 m)) | Mount Everest | 1954 | 45 | 44 | Pakistan[dp 8] China[12]
3 | Kangchenjunga | 8,586 | 28,169 | 3,922 | 12,867 | Kangchenjunga Himalaya | 27°42′12″N 88°08′51″E﻿ / ﻿27.70333°N 88.14750°E﻿ / 27.70333; 88.14750﻿ (3. Kangchenjunga (8586 m)) * | Mount Everest | 1955 | 38 | 24 | Nepal India
4 | Lhotse | 8,516 | 27,940 | 610 | 2,000 | Mahalangur Himalaya | 27°57′42″N 86°55′59″E﻿ / ﻿27.96167°N 86.93306°E﻿ / 27.96167; 86.93306﻿ (4. Lhotse (8516 m)) | Mount Everest | 1956 | 26 | 26 | Nepal China
5 | Makalu | 8,485 | 27,838 | 2,378 | 7,802 | Mahalangur Himalaya | 27°53′23″N 87°05′20″E﻿ / ﻿27.88972°N 87.08889°E﻿ / 27.88972; 87.08889﻿ (5. Makalu (8485 m)) | Mount Everest | 1955 | 45 | — | Nepal China
6 | Cho Oyu | 8,188 | 26,864 [dp 9] | 2,340 | 7,680 | Mahalangur Himalaya | 28°05′39″N 86°39′39″E﻿ / ﻿28.09417°N 86.66083°E﻿ / 28.09417; 86.66083﻿ (6. Cho Oyu (8188 m)) | Mount Everest | 1954 | 79 | 28 | Nepal China
7 | Dhaulagiri I | 8,167 | 26,795 | 3,357 | 11,014 | Dhaulagiri Himalaya | 28°41′48″N 83°29′35″E﻿ / ﻿28.69667°N 83.49306°E﻿ / 28.69667; 83.49306﻿ (7. Dhaulagiri I (8167 m)) | K2 | 1960 | 51 | 39 | Nepal
8 | Manaslu | 8,163 | 26,781 | 3,092 | 10,144 | Manaslu Himalaya | 28°33′00″N 84°33′35″E﻿ / ﻿28.55000°N 84.55972°E﻿ / 28.55000; 84.55972﻿ (8. Manaslu (8163 m)) | Cho Oyu | 1956 | 49 | 45 | Nepal
9 | Nanga Parbat | 8,126 | 26,660 | 4,608 | 15,118 | Nanga Parbat Himalaya | 35°14′14″N 74°35′21″E﻿ / ﻿35.23722°N 74.58917°E﻿ / 35.23722; 74.58917﻿ (9. Nanga Parbat (8126 m)) | Dhaulagiri | 1953 | 52 | 67 | Pakistan[14][dp 8]
10 | Annapurna I | 8,091 | 26,545 | 2,984 | 9,790 | Annapurna Himalaya | 28°35′44″N 83°49′13″E﻿ / ﻿28.59556°N 83.82028°E﻿ / 28.59556; 83.82028﻿ (10. Annapurna I (8091 m)) | Cho Oyu | 1950 | 97 | 88 | Nepal
11 | Gasherbrum I Hidden Peak K5 | 8,080 | 26,510 | 2,155 | 7,070 | Baltoro Karakoram | 35°43′28″N 76°41′47″E﻿ / ﻿35.72444°N 76.69639°E﻿ / 35.72444; 76.69639﻿ (11. Gasherbrum I / Hidden Peak / K5 (8080 m)) | K2 | 1958 | 31 | 16 | Pakistan[dp 8] China[dp 10]
12 | Broad Peak | 8,051 | 26,414 | 1,701 | 5,581 | Baltoro Karakoram | 35°48′38″N 76°34′06″E﻿ / ﻿35.81056°N 76.56833°E﻿ / 35.81056; 76.56833﻿ (12. Broad Peak / K3 (8051 m)) | Gasherbrum I | 1957 | 39 | 19 | Pakistan[dp 8] China[dp 10]
13 | Gasherbrum II K4 | 8,035 | 26,362 | 1,524 | 5,000 | Baltoro Karakoram | 35°45′28″N 76°39′12″E﻿ / ﻿35.75778°N 76.65333°E﻿ / 35.75778; 76.65333﻿ (13. Gasherbrum II / K4 (8035 m)) | Gasherbrum I | 1956 | 54 | 12 | Pakistan[dp 8] China[dp 10]
14 | Shishapangma Gosainthan | 8,027 | 26,335 | 2,897 | 9,505 | Jugal Himalaya | 28°21′12″N 85°46′43″E﻿ / ﻿28.35333°N 85.77861°E﻿ / 28.35333; 85.77861﻿ (14. Shishapangma (8027 m)) | Cho Oyu | 1964 | 43 | 19 | China
15 | Gyachung Kang | 7,952 | 26,089 | 672 | 2,205 | Mahalangur Himalaya | 28°05′53″N 86°44′42″E﻿ / ﻿28.09806°N 86.74500°E﻿ / 28.09806; 86.74500﻿ (15. Gyachung Kang (7952 m)) | Cho Oyu | 1964 | 5 | 3 | Nepal China
S | Gasherbrum III K3a | 7,946 | 26,070 | 355 | 1,165 | Baltoro Karakoram | 35°45′33″N 76°38′30″E﻿ / ﻿35.75917°N 76.64167°E﻿ / 35.75917; 76.64167﻿ (Gasherbrum III (7946 m)) | Gasherbrum II | 1975 | 2 | 2 | Pakistan[dp 8] China[dp 10]
16 | Annapurna II | 7,937 | 26,040 | 2,437 | 7,995 | Annapurna Himalaya | 28°32′05″N 84°07′19″E﻿ / ﻿28.53472°N 84.12194°E﻿ / 28.53472; 84.12194﻿ (16. Annapurna II (7937 m)) | Annapurna I | 1960 | 6 | 19 | Nepal
17 | Gasherbrum IV K3 | 7,932 | 26,024 | 712 | 2,336 | Baltoro Karakoram | 35°45′38″N 76°36′58″E﻿ / ﻿35.76056°N 76.61611°E﻿ / 35.76056; 76.61611﻿ (17. Gasherbrum IV (7932 m)) | Gasherbrum III | 1958 | 4 | 11 | Pakistan[dp 8]
18 | Himalchuli | 7,893 | 25,896 | 1,633 | 5,358 | Manaslu Himalaya | 28°26′12″N 84°38′23″E﻿ / ﻿28.43667°N 84.63972°E﻿ / 28.43667; 84.63972﻿ (18. Himalchuli (7893 m)) * | Manaslu | 1960 | 6 | 12 | Nepal
19 | Distaghil Sar | 7,884 | 25,866 | 2,525 | 8,284 | Hispar Karakoram | 36°19′33″N 75°11′16″E﻿ / ﻿36.32583°N 75.18778°E﻿ / 36.32583; 75.18778﻿ (19. Distaghil Sar (7884 m)) | K2 | 1960 | 3 | 5 | Pakistan[dp 8]
20 | Ngadi Chuli | 7,871 | 25,823 | 1,011 | 3,317 | Manaslu Himalaya | 28°30′12″N 84°34′00″E﻿ / ﻿28.50333°N 84.56667°E﻿ / 28.50333; 84.56667﻿ (20. Ngadi Chuli (7871 m)) | Manaslu | 1979 | 1 | 6 | Nepal
S | Nuptse | 7,864 | 25,801 | 305 | 1,001 | Mahalangur Himalaya | 27°58′03″N 86°53′13″E﻿ / ﻿27.96750°N 86.88694°E﻿ / 27.96750; 86.88694﻿ (Nuptse (7864 m)) | Lhotse | 1961 | 5 | 12 | Nepal
21 | Khunyang Chhish | 7,823 | 25,666 | 1,765 | 5,791 | Hispar Karakoram | 36°12′19″N 75°12′28″E﻿ / ﻿36.20528°N 75.20778°E﻿ / 36.20528; 75.20778﻿ (21. Khunyang Chhish (7823 m)) * | Distaghil Sar | 1971 | 2 | 6 | Pakistan[dp 8]
22 | Masherbrum K1 | 7,821 | 25,659 | 2,457 | 8,061 | Masherbrum Karakoram | 35°38′28″N 76°18′21″E﻿ / ﻿35.64111°N 76.30583°E﻿ / 35.64111; 76.30583﻿ (22. Masherbrum / K1 (7821 m)) | Gasherbrum I | 1960 | 4 | 9 | Pakistan[dp 8]
23 | Nanda Devi | 7,816 | 25,643 | 3,139 | 10,299 | Garhwal Himalaya | 30°22′33″N 79°58′15″E﻿ / ﻿30.37583°N 79.97083°E﻿ / 30.37583; 79.97083﻿ (23. Nanda Devi (7816 m)) | Dhaulagiri | 1936 | 14 | 12 | India
24 | Chomo Lonzo | 7,804 | 25,604 | 590 | 1,940 | Mahalangur Himalaya | 27°55′50″N 87°06′28″E﻿ / ﻿27.93056°N 87.10778°E﻿ / 27.93056; 87.10778﻿ (24. Chomo Lonzo (7804 m)) | Makalu | 1954 | 3 | 1 | China
25 | Batura Sar | 7,795 | 25,574 | 3,118 | 10,230 | Batura Karakoram | 36°30′37″N 74°31′21″E﻿ / ﻿36.51028°N 74.52250°E﻿ / 36.51028; 74.52250﻿ (25. Batura Sar (7795 m)) | Distaghil Sar | 1976 | 4 | 6 | Pakistan[dp 8]
26 | Rakaposhi | 7,788 | 25,551 | 2,818 | 9,245 | Rakaposhi-Haramosh Karakoram | 36°08′33″N 74°29′22″E﻿ / ﻿36.14250°N 74.48944°E﻿ / 36.14250; 74.48944﻿ (26. Rakaposhi (7788 m)) | Khunyang Chhish | 1958 | 8 | 13 | Pakistan[dp 8]
27 | Namcha Barwa | 7,782 | 25,531 | 4,106 | 13,471 | Assam Himalaya | 29°37′52″N 95°03′19″E﻿ / ﻿29.63111°N 95.05528°E﻿ / 29.63111; 95.05528﻿ (27. Namcha Barwa (7782 m)) | Kangchenjunga | 1992 | 1 | 2 | China
28 | Kanjut Sar | 7,760 | 25,460 | 1,660 | 5,450 | Hispar Karakoram | 36°12′20″N 75°25′01″E﻿ / ﻿36.20556°N 75.41694°E﻿ / 36.20556; 75.41694﻿ (28. Kanjut Sar (7760 m)) | Khunyang Chhish | 1959 | 2 | 1 | Pakistan[dp 8]
29 | Kamet | 7,756 | 25,446 | 2,825 | 9,268 | Garhwal Himalaya | 30°55′12″N 79°35′30″E﻿ / ﻿30.92000°N 79.59167°E﻿ / 30.92000; 79.59167﻿ (29. Kamet (7756 m)) * | Nanda Devi | 1931 | 23 | 14 | India
30 | Dhaulagiri II | 7,751 | 25,430 | 2,397 | 7,864 | Dhaulagiri Himalaya | 28°45′46″N 83°23′18″E﻿ / ﻿28.76278°N 83.38833°E﻿ / 28.76278; 83.38833﻿ (30. Dhaulagiri II (7751 m)) | Dhaulagiri | 1971 | 4 | 11 | Nepal
31 | Saltoro Kangri K10 | 7,742 | 25,400 | 2,160 | 7,090 | Saltoro Karakoram | 35°23′57″N 76°50′53″E﻿ / ﻿35.39917°N 76.84806°E﻿ / 35.39917; 76.84806﻿ (31. Saltoro Kangri / K10 (7742 m)) * | Gasherbrum I | 1962 | 2 | 1 | India Pakistan[dp 8] [dp 11]
32 | Kumbhakarna Jannu | 7,711 | 25,299 | 1,036 | 3,399 | Kangchenjunga Himalaya | 27°40′56″N 88°02′40″E﻿ / ﻿27.68222°N 88.04444°E﻿ / 27.68222; 88.04444﻿ (32. Jannu (7711 m)) * | Kangchenjunga | 1962 | 17 | 12 | Nepal
33 | Tirich Mir | 7,708 | 25,289 | 3,910 | 12,830 | Hindu Kush | 36°15′19″N 71°50′30″E﻿ / ﻿36.25528°N 71.84167°E﻿ / 36.25528; 71.84167﻿ (33. Tirich Mir (7708 m)) * | Batura Sar | 1950 | 20 | 11 | Pakistan
S | Molamenqing | 7,703 | 25,272 | 433 | 1,421 | Langtang Himalaya | 28°21′18″N 85°48′35″E﻿ / ﻿28.35500°N 85.80972°E﻿ / 28.35500; 85.80972﻿ (Molamenqing (7703 m)) | Shishapangma | 1981 | 1 | 0 | China
34 | Gurla Mandhata | 7,694 | 25,243 | 2,788 | 9,147 | Nalakankar Himalaya | 30°26′19″N 81°17′48″E﻿ / ﻿30.43861°N 81.29667°E﻿ / 30.43861; 81.29667﻿ (34. Gurla Mandhata (7694 m)) | Dhaulagiri | 1985 | 6 | 4 | China
35 | Saser Kangri I K22 | 7,672 | 25,171 | 2,304 | 7,559 | Saser Karakoram | 34°52′00″N 77°45′09″E﻿ / ﻿34.86667°N 77.75250°E﻿ / 34.86667; 77.75250﻿ (35. Saser Kangri I / K22 (7672 m)) | Gasherbrum I | 1973 | 6 | 4 | India[dp 12]
36 | Chogolisa | 7,665 | 25,148 | 1,624 | 5,328 | Masherbrum Karakoram | 35°36′47″N 76°34′29″E﻿ / ﻿35.61306°N 76.57472°E﻿ / 35.61306; 76.57472﻿ (36. Chogolisa (7665 m)) | Gasherbrum I | 1975 | 4 | 2 | Pakistan[dp 8]
S | Dhaulagiri IV | 7,661 | 25,135 | 469 | 1,539 | Dhaulagiri Himalaya | 28°44′09″N 83°18′55″E﻿ / ﻿28.73583°N 83.31528°E﻿ / 28.73583; 83.31528﻿ (Dhaulagiri IV (7661 m)) | Dhaulagiri II | 1975 | 2 | 10 | Nepal
37 | Kongur Tagh | 7,649 | 25,095 | 3,585 | 11,762 | Kongur Shan (Eastern Pamirs) | 38°35′36″N 75°18′48″E﻿ / ﻿38.59333°N 75.31333°E﻿ / 38.59333; 75.31333﻿ (37. Kongur Tagh (7649 m)) | Distaghil Sar | 1981 | 2 | 4 | China
S | Dhaulagiri V | 7,618 | 24,993 | 340 | 1,120 | Dhaulagiri Himalaya | 28°44′02″N 83°21′41″E﻿ / ﻿28.73389°N 83.36139°E﻿ / 28.73389; 83.36139﻿ (Dhaulagiri V (7618 m)) * | Dhaulagiri IV | 1975 | 2 | 3 | Nepal
38 | Shispare | 7,611 | 24,970 | 1,240 | 4,070 | Batura Karakoram | 36°26′26″N 74°40′51″E﻿ / ﻿36.44056°N 74.68083°E﻿ / 36.44056; 74.68083﻿ (38. Shispare (7611 m)) | Batura Sar | 1974 | 3 | 1 | Pakistan[dp 8]
39 | Trivor | 7,577 | 24,859 | 997 | 3,271 | Hispar Karakoram | 36°17′15″N 75°05′06″E﻿ / ﻿36.28750°N 75.08500°E﻿ / 36.28750; 75.08500﻿ (39. Trivor (7577 m)) * | Distaghil Sar | 1960 | 2 | 5 | Pakistan[dp 8]
40 | Gangkhar Puensum | 7,570 | 24,840 | 2,995 | 9,826 | Kula Kangri Himalaya | 28°02′50″N 90°27′19″E﻿ / ﻿28.04722°N 90.45528°E﻿ / 28.04722; 90.45528﻿ (40. Gangkhar Puensum (7570 m)) * | Kangchenjunga | none | 0 | 3 | Bhutan China
41 | Gongga Shan Minya Konka | 7,556 | 24,790 | 3,642 | 11,949 | Daxue Mountains (Hengduan Shan) | 29°35′43″N 101°52′47″E﻿ / ﻿29.59528°N 101.87972°E﻿ / 29.59528; 101.87972﻿ (41. Gongga Shan / Minya Konka (7556 m)) | Mount Everest | 1932 | 6 | 7 | China
42 | Annapurna III | 7,555 | 24,787 | 703 | 2,306 | Annapurna Himalaya | 28°35′06″N 83°59′24″E﻿ / ﻿28.58500°N 83.99000°E﻿ / 28.58500; 83.99000﻿ (42. Annapurna III (7555 m)) | Annapurna I | 1961 | 10 | 17 | Nepal
43 | Skyang Kangri | 7,545 | 24,754 | 1,085 | 3,560 | Baltoro Karakoram | 35°55′35″N 76°34′03″E﻿ / ﻿35.92639°N 76.56750°E﻿ / 35.92639; 76.56750﻿ (43. Skyang Kangri (7545 m)) | K2 | 1976 | 1 | 2 | Pakistan[dp 8] China[dp 10]
44 | Changtse | 7,543 | 24,747 [dp 13] | 514 | 1,686 | Mahalangur Himalaya | 28°01′29″N 86°54′51″E﻿ / ﻿28.02472°N 86.91417°E﻿ / 28.02472; 86.91417﻿ (44. Changtse (7543 m)) | Mount Everest | 1982 | 9 | 9 | China
45 | Kula Kangri | 7,538 | 24,731 | 1,654 | 5,427 | Kula Kangri Himalaya | 28°13′37″N 90°36′59″E﻿ / ﻿28.22694°N 90.61639°E﻿ / 28.22694; 90.61639﻿ (45. Kula Kangri (7538 m)) | Gangkhar Puensum | 1986 | 3 | 2 | China Bhutan [dp 14]
46 | Kongur Tiube | 7,530 | 24,700 | 840 | 2,760 | Kongur Shan (Eastern Pamirs) | 38°36′57″N 75°11′45″E﻿ / ﻿38.61583°N 75.19583°E﻿ / 38.61583; 75.19583﻿ (46. Kongur Tiube (7530 m)) | Kongur Tagh | 1956 | 2 | 3 | China
S | Annapurna IV | 7,525 | 24,688 | 255 | 837 | Annapurna Himalaya | 28°32′15″N 84°4′58″E﻿ / ﻿28.53750°N 84.08278°E﻿ / 28.53750; 84.08278﻿ (Annapurna IV (7,525 m)) | Annapurna | 1955 | 43 | 18 | Nepal
47 | Mamostong Kangri | 7,516 | 24,659 | 1,803 | 5,915 | Rimo Karakoram | 35°08′31″N 77°34′39″E﻿ / ﻿35.14194°N 77.57750°E﻿ / 35.14194; 77.57750﻿ (47. Mamostong Kangri (7516 m)) | Gasherbrum I | 1984 | 5 | 0 | India[dp 12]
48 | Saser Kangri II E | 7,513 | 24,649 | 1,458 | 4,783 | Saser Karakoram | 34°48′17″N 77°48′24″E﻿ / ﻿34.80472°N 77.80667°E﻿ / 34.80472; 77.80667﻿ (48. Saser Kangri II E (7513 m)) | Saser Kangri I | 2011 | 0 | 0 [dp 15] | India'[dp 12]
49 | Muztagh Ata | 7,509 | 24,636 | 2,698 | 8,852 | Muztagata (Eastern Pamirs) | 38°16′33″N 75°06′58″E﻿ / ﻿38.27583°N 75.11611°E﻿ / 38.27583; 75.11611﻿ (49. Muztagh Ata (7546 m)) | Kongur Tagh | 1956 | many | — | China
50 | Ismoil Somoni Peak | 7,495 | 24,590 | 3,402 | 11,161 | Pamir (Academy of Sciences Range) | 38°56′35″N 72°00′57″E﻿ / ﻿38.94306°N 72.01583°E﻿ / 38.94306; 72.01583﻿ (50. Ismoil Somoni Peak (7495 m)) | Muztagh Ata | 1933 | — | — | Tajikistan
51 | Saser Kangri III | 7,495 | 24,590 | 835 | 2,740 | Saser Karakoram | 34°50′44″N 77°47′06″E﻿ / ﻿34.84556°N 77.78500°E﻿ / 34.84556; 77.78500﻿ (51. Saser Kangri III (7495 m)) | Saser Kangri I | 1986 | 1 | 0 | India'[dp 12]
52 | Noshaq | 7,492 | 24,580 | 2,024 | 6,640 | Hindu Kush | 36°25′56″N 71°49′43″E﻿ / ﻿36.43222°N 71.82861°E﻿ / 36.43222; 71.82861﻿ (52. Noshaq (7492 m)) | Tirich Mir | 1960 | 33 | 3 | Afghanistan Pakistan
53 | Pumari Chhish | 7,492 | 24,580 | 884 | 2,900 | Hispar Karakoram | 36°12′41″N 75°15′01″E﻿ / ﻿36.21139°N 75.25028°E﻿ / 36.21139; 75.25028﻿ (53. Pumari Chhish (7492 m)) | Khunyang Chhish | 1979 | 1 | 2 | Pakistan[dp 8]
54 | Passu Sar | 7,476 | 24,528 | 647 | 2,123 | Batura Karakoram | 36°29′16″N 74°35′16″E﻿ / ﻿36.48778°N 74.58778°E﻿ / 36.48778; 74.58778﻿ (54. Passu Sar (7476 m)) | Batura Sar | 1994 | 1 | 0 | Pakistan[dp 8]
55 | Yukshin Gardan Sar | 7,469 | 24,505 | 1,374 | 4,508 | Hispar Karakoram | 36°15′04″N 75°22′29″E﻿ / ﻿36.25111°N 75.37472°E﻿ / 36.25111; 75.37472﻿ (55. Yukshin Gardan Sar (7469 m)) | Pumari Chhish | 1984 | 4 | 1 | Pakistan[dp 8]
56 | Teram Kangri I | 7,462 | 24,482 | 1,703 | 5,587 | Siachen Karakoram | 35°34′48″N 77°04′42″E﻿ / ﻿35.58000°N 77.07833°E﻿ / 35.58000; 77.07833﻿ (56. Teram Kangri I (7462 m)) | Gasherbrum I | 1975 | 2 | 0 | India China [dp 10][dp 11]'[dp 12]
57 | Jongsong Peak | 7,462 | 24,482 | 1,298 | 4,259 | Kangchenjunga Himalaya | 27°52′54″N 88°08′09″E﻿ / ﻿27.88167°N 88.13583°E﻿ / 27.88167; 88.13583﻿ (57. Jongsong Peak (7462 m)) | Kangchenjunga | 1930 | 2 | 3 | India China Nepal
58 | Malubiting | 7,458 | 24,469 | 2,193 | 7,195 | Rakaposhi-Haramosh Karakoram | 36°00′12″N 74°52′31″E﻿ / ﻿36.00333°N 74.87528°E﻿ / 36.00333; 74.87528﻿ (58. Malubiting (7458 m)) | Rakaposhi | 1971 | 2 | 6 | Pakistan[dp 8]
59 | Gangapurna | 7,455 | 24,459 | 563 | 1,847 | Annapurna Himalaya | 28°36′18″N 83°57′49″E﻿ / ﻿28.60500°N 83.96361°E﻿ / 28.60500; 83.96361﻿ (59. Gangapurna (7455 m)) | Annapurna III | 1965 | 8 | 13 | Nepal
60 | Jengish Chokusu Tömür Pik Pobedy | 7,439 | 24,406 | 4,148 | 13,609 | Tian Shan | 42°02′05″N 80°07′47″E﻿ / ﻿42.03472°N 80.12972°E﻿ / 42.03472; 80.12972﻿ (60. Jengish Chokusu / Tömür / Pk Pobeda (7439 m)) | Ismail Samani Peak | 1956 | — | — | Kyrgyzstan China
S | Sunanda Devi Nanda Devi East | 7,434 | 24,390 | 229 | 751 | Garhwal Himalaya | 30°22′00″N 79°59′40″E﻿ / ﻿30.36667°N 79.99444°E﻿ / 30.36667; 79.99444﻿ (Sunanda Devi (7434 m)) | Nanda Devi | 1939 | 14 | 12 | India
61 | K12 | 7,428 | 24,370 | 1,978 | 6,490 | Saltoro Karakoram | 35°17′45″N 77°01′20″E﻿ / ﻿35.29583°N 77.02222°E﻿ / 35.29583; 77.02222﻿ (61. K12 (7428 m)) | Saltoro Kangri | 1974 | 4 | 2 | India Pakistan [dp 8][dp 11]
62 | Yangra Ganesh I | 7,422 | 24,350 | 2,352 | 7,717 | Ganesh Himalaya | 28°23′29″N 85°07′38″E﻿ / ﻿28.39139°N 85.12722°E﻿ / 28.39139; 85.12722﻿ (62. Yangra / Ganesh I (7422 m)) | Shishapangma | 1955 | 1 | 6 | Nepal China
63 | Sia Kangri | 7,422 | 24,350 | 642 | 2,106 | Siachen Karakoram | 35°39′48″N 76°45′42″E﻿ / ﻿35.66333°N 76.76167°E﻿ / 35.66333; 76.76167﻿ (63. Sia Kangri (7422 m)) | Gasherbrum I | 1934 | 6 | 0 | Pakistan China [dp 10][dp 11]
64 | Momhil Sar | 7,414 | 24,324 | 907 | 2,976 | Hispar Karakoram | 36°19′04″N 75°02′11″E﻿ / ﻿36.31778°N 75.03639°E﻿ / 36.31778; 75.03639﻿ (64. Momhil Sar (7414 m)) * | Trivor | 1964 | 2 | 6 | Pakistan[dp 8]
65 | Kabru N | 7,412 | 24,318 | 720 | 2,360 | Kangchenjunga Himalaya | 27°38′02″N 88°07′00″E﻿ / ﻿27.63389°N 88.11667°E﻿ / 27.63389; 88.11667﻿ (65. Kabru N (7412 m)) | Kangchenjunga | 1994 | 1 | 2 [16] | India Nepal
66 | Skil Brum | 7,410 | 24,310 | 1,152 | 3,780 | Baltoro Karakoram | 35°51′03″N 76°25′43″E﻿ / ﻿35.85083°N 76.42861°E﻿ / 35.85083; 76.42861﻿ (66. Skil Brum (7410 m)) | K2 | 1957 | 2 | 1 | Pakistan[dp 8]
67 | Haramosh Peak | 7,409 | 24,308 | 2,277 | 7,470 | Rakaposhi-Haramosh Karakoram | 35°50′24″N 74°53′51″E﻿ / ﻿35.84000°N 74.89750°E﻿ / 35.84000; 74.89750﻿ (67. Haramosh Peak (7409 m)) | Malubiting | 1958 | 4 | 3 | Pakistan[dp 8]
68 | Istor-o-Nal | 7,403 | 24,288 | 1,043 | 3,422 | Hindu Kush | 36°22′32″N 71°53′54″E﻿ / ﻿36.37556°N 71.89833°E﻿ / 36.37556; 71.89833﻿ (68. Istor-o-Nal (7403 m)) | Noshaq | 1969 | 4 | 5 | Pakistan
69 | Ghent Kangri | 7,401 | 24,281 | 1,493 | 4,898 | Saltoro Karakoram | 35°31′04″N 76°48′02″E﻿ / ﻿35.51778°N 76.80056°E﻿ / 35.51778; 76.80056﻿ (69. Ghent Kangri (7401 m)) | Saltoro Kangri | 1961 | 4 | 0 | India Pakistan [dp 8][dp 11]
70 | Ultar | 7,388 | 24,239 | 688 | 2,257 | Batura Karakoram | 36°23′27″N 74°43′00″E﻿ / ﻿36.39083°N 74.71667°E﻿ / 36.39083; 74.71667﻿ (70. Ultar (7388 m)) | Shispare | 1996 | 2 | 5 | Pakistan[dp 8]
71 | Rimo I | 7,385 | 24,229 | 1,428 | 4,685 | Rimo Karakoram | 35°21′18″N 77°22′08″E﻿ / ﻿35.35500°N 77.36889°E﻿ / 35.35500; 77.36889﻿ (71. Rimo I (7385 m)) | Teram Kangri I | 1988 | 1 | 3 | India[dp 16]
72 | Churen Himal | 7,385 | 24,229 | 650 | 2,130 | Dhaulagiri Himalaya | 28°44′05″N 83°13′03″E﻿ / ﻿28.73472°N 83.21750°E﻿ / 28.73472; 83.21750﻿ (72. Churen Himal (7385 m)) | Dhaulagiri IV | 1970 | 3 | 0 | Nepal
73 | Teram Kangri III | 7,382 | 24,219 | 520 | 1,710 | Siachen Karakoram | 35°35′59″N 77°02′53″E﻿ / ﻿35.59972°N 77.04806°E﻿ / 35.59972; 77.04806﻿ (73. Teram Kangri III (7382 m)) | Teram Kangri I | 1979 | 1 | 0 | India China [dp 10][dp 11]'[dp 12]
74 | Sherpi Kangri | 7,380 | 24,210 | 1,320 | 4,330 | Saltoro Karakoram | 35°27′58″N 76°46′53″E﻿ / ﻿35.46611°N 76.78139°E﻿ / 35.46611; 76.78139﻿ (74. Sherpi Kangri (7380 m)) * | Ghent Kangri | 1976 | 1 | 1 | India Pakistan [dp 8][dp 11]'[dp 12]
75 | Labuche Kang | 7,367 | 24,170 | 1,957 | 6,421 | Labuche Himalaya | 28°18′15″N 86°21′03″E﻿ / ﻿28.30417°N 86.35083°E﻿ / 28.30417; 86.35083﻿ (75. Labuche Kang (7367 m)) | Cho Oyu | 1987 | 1 | 0 | China
76 | Kirat Chuli | 7,362 | 24,154 | 1,168 | 3,832 | Kangchenjunga Himalaya | 27°47′16″N 88°11′43″E﻿ / ﻿27.78778°N 88.19528°E﻿ / 27.78778; 88.19528﻿ (76. Kirat Chuli (7362 m)) | Kangchenjunga | 1939 | 1 | 6 | India Nepal
S | Abi Gamin | 7,355 | 24,131 | 217 | 712 | Garhwal Himalaya | 30°55′57″N 79°36′09″E﻿ / ﻿30.93250°N 79.60250°E﻿ / 30.93250; 79.60250﻿ (Abi Gamin (7355 m)) | Kamet | 1950 | 17 | 2 | India China
S | Gimmigela Chuli The Twins | 7,350 | 24,110 | 432 | 1,417 | Kangchenjunga Himalaya | 27°44′27″N 88°09′31″E﻿ / ﻿27.74083°N 88.15861°E﻿ / 27.74083; 88.15861﻿ (Gimmigela / The Twins (7350 m)) | Kangchenjunga | 1994 | 3 | 1 | India Nepal
S | Nangpai Gosum | 7,350 | 24,110 | 427 | 1,401 | Mahalangur Himalaya | 28°04′24″N 86°36′51″E﻿ / ﻿28.07333°N 86.61417°E﻿ / 28.07333; 86.61417﻿ (Nangpai Gosum (7350 m)) | Cho Oyu | 1986 |  | 1 [17] | Nepal China
77 | Saraghrar | 7,349 | 24,111 | 1,979 | 6,493 | Hindu Kush | 36°32′51″N 72°06′54″E﻿ / ﻿36.54750°N 72.11500°E﻿ / 36.54750; 72.11500﻿ (77. Saraghrar (7349 m)) | Noshaq | 1959 | 2 | 3 | Pakistan
S | Talung | 7,349 | 24,111 | 366 | 1,201 | Kangchenjunga Himalaya | 27°39′18″N 88°07′51″E﻿ / ﻿27.65500°N 88.13083°E﻿ / 27.65500; 88.13083﻿ (Talung (7349 m)) * | Kabru | 1964 | 3 | 4 [18] | Nepal India
78 | Jomolhari Chomo Lhari | 7,326 | 24,035 | 2,341 | 7,680 | Jomolhari Himalaya | 27°49′36″N 89°16′04″E﻿ / ﻿27.82667°N 89.26778°E﻿ / 27.82667; 89.26778﻿ (78. Jomolhari (7326 m)) * | Gangkhar Puensum | 1937 | 4 | 0 | Bhutan China
79 | Chamlang | 7,321 | 24,019 | 1,241 | 4,072 | Mahalangur Himalaya | 27°46′30″N 86°58′47″E﻿ / ﻿27.77500°N 86.97972°E﻿ / 27.77500; 86.97972﻿ (79. Chamlang (7321 m)) | Lhotse | 1961 | 7 | 1 | Nepal
80 | Chongtar | 7,315 | 23,999 | 1,295 | 4,249 | Baltoro Karakoram | 35°54′55″N 76°25′45″E﻿ / ﻿35.91528°N 76.42917°E﻿ / 35.91528; 76.42917﻿ (80. Chongtar (7315 m)) | Skil Brum | 1994 | 1 | 1 | China[dp 10]
81 | Baltoro Kangri | 7,312 | 23,990 | 1,140 | 3,740 | Masherbrum Karakoram | 35°38′21″N 76°40′24″E﻿ / ﻿35.63917°N 76.67333°E﻿ / 35.63917; 76.67333﻿ (81. Baltoro Kangri (7312 m)) | Chogolisa | 1963 | 1 | 0 | Pakistan[dp 8]
82 | Siguang Ri | 7,309 | 23,980 | 669 | 2,195 | Mahalangur Himalaya | 28°08′50″N 86°41′06″E﻿ / ﻿28.14722°N 86.68500°E﻿ / 28.14722; 86.68500﻿ (82. Siguang Ri (7309 m)) | Cho Oyu | 1989 | 2 | 1 | China
83 | The Crown Huang Guan Shan | 7,295 | 23,934 | 1,919 | 6,296 | Yengisogat Karakoram | 36°06′24″N 76°12′21″E﻿ / ﻿36.10667°N 76.20583°E﻿ / 36.10667; 76.20583﻿ (83. The Crown / Huang Guan (7295 m)) | Skil Brum (K2) | 1993 | 1 | 5 | China[dp 10]
84 | Gyala Peri | 7,294 | 23,930 | 2,942 | 9,652 | Assam Himalaya | 29°48′52″N 94°58′07″E﻿ / ﻿29.81444°N 94.96861°E﻿ / 29.81444; 94.96861﻿ (84. Gyala Peri (7294 m)) | Mount Everest | 1986 | 1 | 0 | China
85 | Porong Ri | 7,292 | 23,924 | 512 | 1,680 | Langtang Himalaya | 28°23′22″N 85°43′12″E﻿ / ﻿28.38944°N 85.72000°E﻿ / 28.38944; 85.72000﻿ (85. Porong Ri (7292 m)) | Shishapangma | 1982 | 5 | 0 | China
86 | Baintha Brakk The Ogre | 7,285 | 23,901 | 1,891 | 6,204 | Panmah Karakoram | 35°56′51″N 75°45′12″E﻿ / ﻿35.94750°N 75.75333°E﻿ / 35.94750; 75.75333﻿ (86. Baintha Brakk / The Ogre (7285 m)) * | Kanjut Sar | 1977 | 3 | 13 | Pakistan[dp 8]
87 | Yutmaru Sar | 7,283 | 23,894 | 680 | 2,230 | Hispar Karakoram | 36°13′35″N 75°22′02″E﻿ / ﻿36.22639°N 75.36722°E﻿ / 36.22639; 75.36722﻿ (87. Yutmaru Sar (7283 m)) | Yukshin Gardan Sar | 1980 | 1 | 1 | Pakistan[dp 8]
88 | K6 Baltistan Peak | 7,282 | 23,891 | 1,962 | 6,437 | Masherbrum Karakoram | 35°25′06″N 76°33′06″E﻿ / ﻿35.41833°N 76.55167°E﻿ / 35.41833; 76.55167﻿ (88. Baltistan Peak / K6 (7282 m)) | Chogolisa | 1970 | 1 | 3 | Pakistan[dp 8]
89 | Kangpenqing Gang Benchhen | 7,281 | 23,888 | 1,345 | 4,413 | Baiku Himalaya | 28°33′03″N 85°32′44″E﻿ / ﻿28.55083°N 85.54556°E﻿ / 28.55083; 85.54556﻿ (89. Kangpenqing / Gang Benchhen (7281 m)) | Shishapangma | 1982 | 1 | 1 | China
90 | Muztagh Tower | 7,276 | 23,871 | 1,710 | 5,610 | Baltoro Karakoram | 35°49′40″N 76°21′40″E﻿ / ﻿35.82778°N 76.36111°E﻿ / 35.82778; 76.36111﻿ (90. Muztagh Tower (7276 m)) | Skil Brum | 1956 | 4 | 2 | Pakistan[dp 8] China[dp 10]
91 | Mana Peak | 7,272 | 23,858 | 732 | 2,402 | Garhwal Himalaya | 30°52′50″N 79°36′55″E﻿ / ﻿30.88056°N 79.61528°E﻿ / 30.88056; 79.61528﻿ (91. Mana Peak (7272 m)) | Kamet | 1937 | 7 | 3 | India
S | Dhaulagiri VI | 7,268 | 23,845 | 488 | 1,601 | Dhaulagiri Himalaya | 28°42′31″N 83°16′27″E﻿ / ﻿28.70861°N 83.27417°E﻿ / 28.70861; 83.27417﻿ (Dhaulagiri VI (7268 m)) | Dhaulagiri IV | 1970 | 5 | 0 | Nepal
92 | Diran | 7,266 | 23,839 | 1,329 | 4,360 | Rakaposhi-Haramosh Karakoram | 36°07′13″N 74°39′42″E﻿ / ﻿36.12028°N 74.66167°E﻿ / 36.12028; 74.66167﻿ (92. Diran (7266 m)) | Malubiting | 1968 | 12 | 8 | Pakistan[dp 8]
93 | Labuche Kang III Labuche Kang East | 7,250 | 23,790 [dp 17] | 570 | 1,870 | Labuche Himalaya | 28°18′05″N 86°23′02″E﻿ / ﻿28.30139°N 86.38389°E﻿ / 28.30139; 86.38389﻿ (93. Labuche Kang III / East (7250 m)) | Labuche Himilaya | none | 0 | 0 | China
94 | Putha Hiunchuli | 7,246 | 23,773 | 1,151 | 3,776 | Dhaulagiri Himalaya | 28°44′52″N 83°08′46″E﻿ / ﻿28.74778°N 83.14611°E﻿ / 28.74778; 83.14611﻿ (94. Putha Hiunchuli (7246 m)) | Churen Himal | 1954 | 11 | 5 | Nepal
95 | Apsarasas Kangri | 7,245 | 23,770 | 607 | 1,991 | Siachen Karakoram | 35°32′19″N 77°08′55″E﻿ / ﻿35.53861°N 77.14861°E﻿ / 35.53861; 77.14861﻿ (95. Apsarasas Kangri (7245 m)) | Teram Kangri I | 1976 | 2 | 0 | India China [dp 10][dp 11]'[dp 12]
96 | Mukut Parbat | 7,242 | 23,760 | 683 | 2,241 | Garhwal Himalaya | 30°56′57″N 79°34′12″E﻿ / ﻿30.94917°N 79.57000°E﻿ / 30.94917; 79.57000﻿ (96. Mukut Parbat (7242 m)) | Kamet | 1951 | 2 | 1 | India China
97 | Rimo III | 7,233 | 23,730 | 613 | 2,011 | Rimo Karakoram | 35°22′31″N 77°21′42″E﻿ / ﻿35.37528°N 77.36167°E﻿ / 35.37528; 77.36167﻿ (97. Rimo III (7233 m)) | Rimo I | 1985 | 1 | 0 | India[dp 16]'[dp 12]
98 | Langtang Lirung | 7,227 | 23,711 | 1,534 | 5,033 | Langtang Himalaya | 28°15′22″N 85°31′01″E﻿ / ﻿28.25611°N 85.51694°E﻿ / 28.25611; 85.51694﻿ (98. Langtang Lirung (7227 m)) | Shishapangma | 1978 | 14 | 13 | Nepal
99 | Karjiang | 7,221 | 23,691 | 895 | 2,936 | Kula Kangri Himalaya | 28°15′27″N 90°38′49″E﻿ / ﻿28.25750°N 90.64694°E﻿ / 28.25750; 90.64694﻿ (99. Karjiang (7221 m)) | Kula Kangri | none | 0 | 2 | China
100 | Annapurna Dakshin (Annapurna South) | 7,219 | 23,684 | 769 | 2,523 | Annapurna Himalaya | 28°31′06″N 83°48′22″E﻿ / ﻿28.51833°N 83.80611°E﻿ / 28.51833; 83.80611﻿ (100. Annapurna Dakshin (7219 m)) | Annapurna | 1964 | 10 | 16 | Nepal
101 | Khartaphu | 7,213 | 23,665 | 712 | 2,336 | Mahalangur Himalaya | 28°03′49″N 86°58′39″E﻿ / ﻿28.06361°N 86.97750°E﻿ / 28.06361; 86.97750﻿ (101. Khartaphu (7213 m)) | Mount Everest | 1935 | 1 | 0 | China
102 | Tongshanjiabu[19] | 7,207 | 23,645 | 1,757 | 5,764 | Lunana Himalaya | 28°11′12″N 89°57′27″E﻿ / ﻿28.18667°N 89.95750°E﻿ / 28.18667; 89.95750﻿ (102. Tongshanjiabu (7207 m)) | Gangkhar Puensum | none | 0 | 0 | Bhutan China [dp 18]
103 | Malangutti Sar | 7,207 | 23,645 | 507 | 1,663 | Hispar Karakoram | 36°21′47″N 75°08′57″E﻿ / ﻿36.36306°N 75.14917°E﻿ / 36.36306; 75.14917﻿ (103. Malangutti Sar (7207 m)) | Distaghil Sar | 1985 | 1 | 0 | Pakistan[dp 8]
104 | Noijin Kangsang Norin Kang | 7,206 | 23,642 | 2,160 | 7,090 | Nagarze Himalaya | 28°56′48″N 90°10′42″E﻿ / ﻿28.94667°N 90.17833°E﻿ / 28.94667; 90.17833﻿ (104. Noijin Kangsang / Norin Kang (7206 m)) | Gangkhar Puensum | 1986 | 4 | 1 | China
105 | Langtang Ri | 7,205 | 23,638 | 665 | 2,182 | Langtang Himalaya | 28°22′53″N 85°41′01″E﻿ / ﻿28.38139°N 85.68361°E﻿ / 28.38139; 85.68361﻿ (105. Langtang Ri (7205 m)) | Shishapangma | 1981 | 4 | 0 | Nepal China
106 | Kangphu Kang Shimokangri | 7,204 | 23,635 | 1,244 | 4,081 | Lunana Himalaya | 28°09′24″N 90°04′15″E﻿ / ﻿28.15667°N 90.07083°E﻿ / 28.15667; 90.07083﻿ (106. Kangphu Kang (7204 m)) | Tongshanjiabu | 2002 | 1 | 0 [20] | Bhutan China[dp 18]
107 | Singhi Kangri | 7,202 | 23,629 | 730 | 2,400 | Siachen Karakoram | 35°35′59″N 76°59′01″E﻿ / ﻿35.59972°N 76.98361°E﻿ / 35.59972; 76.98361﻿ (107. Singhi Kangri (7202 m)) | Teram Kangri III | 1976 | 2 | 0 | India China [dp 10][dp 11]'[dp 12]
108 | Lupghar Sar | 7,200 | 23,600 | 730 | 2,400 | Hispar Karakoram | 36°21′01″N 75°02′13″E﻿ / ﻿36.35028°N 75.03694°E﻿ / 36.35028; 75.03694﻿ (108. Lupghar Sar (7200 m)) * | Momhil Sar | 1979 | 1 | 0 | Pakistan[dp 8]

## Data plots[edit]

### By country[edit]

The following graph ranks the countries by number of mountain peaks over 7,200 metres (23,622 ft) above sea level. Note that 38 peaks are on de facto borders and two (Jongsong Peak and Sia Kangri) are on tripoints.

### Stem and leaf plot[edit]

The following is a stem and leaf plot of the above data. The two digits to the left of the line are the first two digits of the mountain's height (metres), and each digit to the right of the line represents the third digit of the mountain's height. Each number on the right is linked to the corresponding mountain's article. For example, the height of one of the mountains (namely Mount Everest) is 8,848 metres (29,029 ft). Also, it is apparent that there are five mountains above 8,200 metres (26,900 ft).

88 | 4
87 |
86 | 1
85 | 8 1
84 | 8
83 |
82 |
81 | 8 6 6 2
80 | 9 8 5 3 2
79 | 5 4 3 3
78 | 9 8 7 6 2 2 1 0
77 | 9 9 8 8 5 5 4 1 0 0
76 | 9 7 6 6 4 1 1
75 | 7 7 5 5 4 4 4 3 3 1 1
74 | 9 9 9 9 7 6 6 6 5 5 3 3 2 2 2 1 1 1 0 0 0
73 | 8 8 8 8 8 6 6 5 5 5 4 2 1 1 1 0
72 | 9 9 9 8 8 8 8 7 7 6 6 5 4 4 4 3 2 2 1 1 0 0 0 0 0 0 0

## Gallery[edit]

- The fourteen eight-thousanders

- 1. The summit of Mount Everest, the highest point on Earth

- 2. K2, the highest summit of the Karakoram

- 3. Kangchenjunga, the second-highest mountain of the Himalaya

- 4. Lhotse, the third-highest mountain of the Himalaya

- 5. Makalu in the Himalaya

- 6. Cho Oyu in the Himalaya

- 7. Dhaulagiri in the Himalaya

- 8. Manaslu in the Himalaya

- 9. Nanga Parbat in the Himalaya

- 10. Annapurna I in the Himalaya

- 11. Gasherbrum I, the second-highest mountain of the Karakoram

- 12. Broad Peak, the third-highest mountain of the Karakoram

- 13. Gasherbrum II in the Karakoram

- 14. Shishapangma in the Himalaya

## See also[edit]

- List of elevation extremes by country
- List of mountain peaks by prominence
- List of mountain peaks of Uttarakhand
- List of mountain ranges of the world
- List of mountains by elevation
- List of mountains on Mars by height
- List of past presumed highest mountains
- List of tallest mountains in the Solar System
- List of the highest major summits of North America
- List of unclimbed mountains of Nepal
- List of volcanoes by elevation
- Lists of mountains
- Olympus Mons, the tallest mountain on any planet in the Solar System
- Rheasilvia crater's central peak, the tallest mountain in the Solar System

## Notes[edit]

1. ^ Peaks which are considered sub-prominences are given a rank of "S".
2. ^ For Nepal, the heights indicated on the Nepal Topographic Maps are followed. For China and the Baltoro Karakoram, the heights are those of Mi Desheng's "The Maps of Snow Mountains in China". For the Hispar Karakoram the heights on a Russian 1:100,000 topo map.[5] seem to be more accurate than the customarily quoted heights probably based on US army maps from the 50s.[6] Elsewhere, unless otherwise indicated, heights are those in [7]
3. ^ Prominences over 1,500 m were copied from,[8] the remainder corresponds to those listed in [9]
4. ^ Coordinates were established by comparing topographical maps with satellite images and SRTM-derived terrain maps. The terrain maps and satellite images often don't match exactly. An asterisk (*) indicates that the map and image are shifted by more than 100 m (4") and/or that the landscapes around the summit don't match.
5. ^ Here defined as the first higher mountain beyond the key saddle with at least 500 m prominence itself.
6. ^ The number of ascents and failed attempts up to 2004 is extracted from [10] These are the number of expeditions (not individuals) that announced their ascent or attempt in a journal. They are probably quite accurate for the rarely climbed peaks (though omissions were noted), but greatly underestimate the number of ascending parties on the easier and/or more popular mountains, like most eight-thousanders. For instance, Mount Everest has been scaled 2,251 times by individuals up to 2004 .[11]
7. ^ Given the large differences between multiple "definitive" measurements of Mount Everest, the traditional 8,848 m is listed. For more information, see Mount Everest#Surveys.
8. ^ a b c d e f g h i j k l m n o p q r s t u v w x y z aa ab ac ad ae af ag ah ai aj ak In Pakistan's disputed Gilgit-Baltistan region.
9. ^ Cho Oyu's height is 8,188 m according to the Nepal Survey's 1996 topographical map,[13] which represents the best known measurement to date. Previous estimates have been 8,153 m and 8,201 m
10. ^ a b c d e f g h i j k l m In the Trans-Karakoram or Shaksgam Tract, ceded by Pakistan from its disputed Gilgit-Baltistan region to China's Xinjiang Uyghur Autonomous Region, claimed by India as a part of its Ladakh union territory.
11. ^ a b c d e f g h i On the border of the Siachen Glacier area, which is controlled by India, but is also claimed by Pakistan.
12. ^ a b c d e f g h i j In India's disputed Ladakh region, claimed by Pakistan.
13. ^ The 1998 1:50,000 National Geographic map of Mount Everest has a height of 7,583 m for "Bei Peak" and 7,066 m for Bei'ao (North Col), giving a 517 m prominence. Mi Desheng's 1997 1:100,000 map of the Everest region has a 7,543 summit and a 7,042 m indication near the col, not quite corresponding to the lowest pass. His 1975 1:50,000 version (in Chinese only) has Changtse at 7,580 and North Col at 7,028. All maps agree that the eastern summit is the highest.
14. ^ Wholly claimed by China as a part of its Tibet Autonomous Region; on the border with Bhutan according to Bhutan
15. ^ The highest (Eastern) summit of Saser Kangri II was climbed on August 24th, 2011.[15] The lower West peak, 2.5 km away, has been climbed in 1984 and twice since.
16. ^ a b The Rimo mountains are in the Siachen Glacier region controlled by India, but claimed by Pakistan
17. ^ The height is unknown, but over 7,200 metres on both Chinese and Russian maps of the area.
18. ^ a b Wholly claimed by Bhutan, but on the border of the Tibet Autonomous Region according to China.

## References[edit]

1. ^
   McMahon, Mary (January 23, 2021). "How do Scientists Determine the World's Tallest Mountain?". Info Bloom. Retrieved March 13, 2021.
2. ^ Fichtl, Marcus (August 31, 2017). "Guam's Mount Lamlam technically world's tallest mountain, though most of it is underwater". Stars and Stripes. Retrieved March 13, 2021.
3. ^ Krulwich, Robert (April 7, 2007). "The 'Highest' Spot on Earth?". Retrieved 21 March 2009.
4. ^ "Mount Aconcagua". worldatlas.org. Retrieved August 17, 2021.
5. ^ "Hispar area: expedition reports and maps". Archived from the original on 2008-04-27. Retrieved 2008-07-15.
6. ^ "Some Frequently Misquoted Elevations". viewfinderpanoramas.org. Retrieved 2021-07-26.
7. ^ Neate 1990.
8. ^ "The Ultra Project Prominence Lists". Peakfinder. Archived from the original on 2018-11-05.
9. ^ Jurgalski, Eberhard; de Ferranti, Jonathan (2009-05-01). "High Asia - All mountains and main peaks above 6650 m".
10. ^ "Alpine Club Himalayan Index".
11. ^ "Summits and Deaths by year". Everesthistory.com.
12. ^ "K2". Britannica.
13. ^ H8615 (Map). Nepal Survey.
14. ^ "Nanga Parbat". Britannica.
15. ^ "First Ascent of Saser Kangri II". American Alpine Club. Archived from the original on 2011-09-30.
16. ^ Abbey, Major A. (1996). "Kabru - Mountain of the Gods". Himalayan Journal. 52: 29–36.
    In this report the northern and highest point of the massif is called Kabru III (first ascent May 1994) and the central, median height peak is called Kabru North. The latter may have been climbed as early as 1883.
17. ^ Yashima, Hiroshi (1988). "Cho Aui Expedition 1986". Himalayan Journal. 44.
18. ^ Hechtel, Richard (1965). "Talung Peak". AAJ.
    The Himalayan index has the 1964 expedition as an attempt, but Franz Lindner and Tenzing Nindra did claim the summit.
19. ^ The name and information about this summit was extracted from the May 2003 edition of Japanese Alpine News.
20. ^ Nakamura, Tamotsu (2002). "First Ascent of Shimokangri on Tibet-Bhutan border" (PDF). Man and Mountain: 41–44.

## Sources[edit]

- Desheng, Mi (1990s). The Maps of Snow Mountains in China. Chinese Academy of Sciences.
- Finnish Meteorological Inst. (1990s). Nepal Topographic Maps. Nepalese Survey Dept.
- "High Mountain Info". High Mountain Sports Magazine (now Climb Magazine). (1990–2005).
- Neate, Jill (1990). High Asia: An Illustrated History of the 7,000 Metre Peaks. Mountaineers Books.
- Some other topographic maps and much from the external links listed above
- Soviet military 1:100,000 topographic maps (most from 1980 to 1981)[citation needed]

## External links[edit]

- SummitPost.org (currently with detailed description of 30 of the top 100 peaks)
- Prominence lists (including all mountains in the world with >1,450m prominence)
- Alpine Club Himalayan index (Especially informative for history of ascents and location of obscure peaks)
- Discussion of frequently misquoted elevations
- BlankontheMap site on mountains of Northern Kashmir
- Digital elevation data, including all the above peaks and many more worldwide
- Hispar area: expedition reports and maps
- List of highest mountains down to 6750 metres
- Google Earth Community (Google Earth KMZ file of Wikipedia list of highest mountains)
- List of worlds highest mountains in Nepal

Retrieved from "https://en.wikipedia.org/w/index.php?title=List_of_highest_mountains_on_Earth&oldid=1102679564"
Categories:

- Lists of highest points
- Lists of mountains by elevation
- Highest things

Hidden categories:

- Pages using the EasyTimeline extension
- Articles with short description
- Short description matches Wikidata
- Articles that may contain original research from September 2021
- All articles that may contain original research
- All articles with unsourced statements
- Articles with unsourced statements from March 2021
- Articles with unsourced statements from December 2009
- Lists of coordinates
- Geographic coordinate lists
- Articles with Geo
- Articles containing potentially dated statements from December 2018
- All articles containing potentially dated statements
- Articles with unsourced statements from July 2018